@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11965 2020-03-05 11:53:49Z Lavender $
+# $Id: admin.py 12719 2021-01-31 06:32:27Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,14 +11,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $
-# $Date: 2020-03-05 20:53:49 +0900 (週四, 05 三月 2020) $
-# $Revision: 11965 $
+# $Author: Casey $
+# $Date: 2021-01-31 14:32:27 +0800 (Sun, 31 Jan 2021) $
+# $Revision: 12719 $
 
 import os
 import datetime
 import hashlib
 import shutil
+import random
+import string
 
 from functools import update_wrapper
 from django.contrib import admin
@@ -51,6 +53,9 @@ TEXT_SUB_FILE_NAME = [
 IMAGE_SUB_FILE_NAME = [
     'jpg', 'png', 'jpeg', 'bmp', 'gif', 'tif',
 ]
+EXCEL_SUB_FILE_NAME = [
+    'xlsx',
+]
 
 logger = createLogger(__name__)
 
@@ -59,6 +64,14 @@ class FolderFrom(forms.ModelForm):
         model = Static
         exclude = ('parent', 'type', 'name')
 
+class ExcelFrom(forms.ModelForm):
+    file = forms.FileField(
+        label=_('File'), required=False)
+
+    class Meta(object):
+        model = Static
+        exclude = ('parent', 'type', 'name')
+
 class TextFrom(forms.ModelForm):
     content = forms.CharField(
         label=_('Content'), widget=forms.Textarea, required=False)
@@ -87,6 +100,12 @@ def createVersion(model, node, conflict=False):
     dirName = node.dirName
     checksum = hashlib.md5(data).hexdigest()
 
+    if subFileName == 'xlsx':
+        randomDigits = ''.join(random.choice(string.digits) for _ in range(2))
+        randomDigits2 = ''.join(random.choice(string.digits) for _ in range(2))
+        randomDigits3 = ''.join(random.choice(string.digits) for _ in range(2))
+        checksum = hashlib.md5(f'{data}\\{randomDigits}\\{randomDigits2}\\{randomDigits3}'.encode('utf-8')).hexdigest()
+
     createFile = False
 
     if Version.objects.filter(dirName=dirName).exists():
@@ -315,6 +334,8 @@ class BaseFileAdmin(admin.ModelAdmin):
             form.base_fields['content'].initial = data
         elif subFileName in IMAGE_SUB_FILE_NAME:
             form = ImageFrom
+        elif subFileName in EXCEL_SUB_FILE_NAME:
+            form = ExcelFrom
         else:
             form = FolderFrom
 
